@@ -3,7 +3,8 @@ package k8shandler
 import (
 	"testing"
 
-	api "github.com/openshift/elasticsearch-operator/pkg/apis/elasticsearch/v1"
+	api "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
+	v1 "k8s.io/api/core/v1"
 )
 
 func TestSelectorsBothUndefined(t *testing.T) {
@@ -255,3 +256,124 @@ func TestSingleNodeNoReplicaCount(t *testing.T) {
 	}
 
 }
+
+func TestNoTolerations(t *testing.T) {
+	commonTolerations := []v1.Toleration{}
+
+	nodeTolerations := []v1.Toleration{}
+
+	expected := []v1.Toleration{}
+
+	actual := appendTolerations(nodeTolerations, commonTolerations)
+
+	if !areTolerationsSame(actual, expected) {
+		t.Errorf("Expected %v but got %v", expected, actual)
+	}
+}
+
+func TestNoNodeTolerations(t *testing.T) {
+	commonTolerations := []v1.Toleration{
+		v1.Toleration{
+			Key:      "node.kubernetes.io/disk-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+	}
+
+	nodeTolerations := []v1.Toleration{}
+
+	expected := []v1.Toleration{
+		v1.Toleration{
+			Key:      "node.kubernetes.io/disk-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+	}
+
+	actual := appendTolerations(nodeTolerations, commonTolerations)
+
+	if !areTolerationsSame(actual, expected) {
+		t.Errorf("Expected %v but got %v", expected, actual)
+	}
+}
+
+func TestNoCommonTolerations(t *testing.T) {
+	commonTolerations := []v1.Toleration{}
+
+	nodeTolerations := []v1.Toleration{
+		v1.Toleration{
+			Key:      "node.kubernetes.io/disk-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+	}
+
+	expected := []v1.Toleration{
+		v1.Toleration{
+			Key:      "node.kubernetes.io/disk-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+	}
+
+	actual := appendTolerations(nodeTolerations, commonTolerations)
+
+	if !areTolerationsSame(actual, expected) {
+		t.Errorf("Expected %v but got %v", expected, actual)
+	}
+}
+
+func TestTolerations(t *testing.T) {
+	commonTolerations := []v1.Toleration{
+		v1.Toleration{
+			Key:      "node.kubernetes.io/disk-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+	}
+
+	nodeTolerations := []v1.Toleration{
+		v1.Toleration{
+			Key:      "node.kubernetes.io/memory-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+	}
+
+	expected := []v1.Toleration{
+		v1.Toleration{
+			Key:      "node.kubernetes.io/disk-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+		v1.Toleration{
+			Key:      "node.kubernetes.io/memory-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+	}
+
+	actual := appendTolerations(nodeTolerations, commonTolerations)
+
+	if !areTolerationsSame(actual, expected) {
+		t.Errorf("Expected %v but got %v", expected, actual)
+	}
+
+	// ensure that ordering does not make a difference
+	expected = []v1.Toleration{
+		v1.Toleration{
+			Key:      "node.kubernetes.io/memory-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+		v1.Toleration{
+			Key:      "node.kubernetes.io/disk-pressure",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+	}
+
+	if !areTolerationsSame(actual, expected) {
+		t.Errorf("Expected %v but got %v", expected, actual)
+	}
+}
